==> weixin2-1.0.6.jar: wechat/sqls/newproduct/searchUserHandPlanDetailToNew.sql <==
/** 查询用户抄表明细 **/
select * from (SELECT
                   f_oughtamount,
                   f_oughtfee,
                   f_tablebase,
                   f_last_tablebase,
                   f_balance,
                   f_curbalance,
                   f_input_date,
                   c.*
               FROM t_handplan h with(nolock)
left join (
	select
		f_hand_id,
		isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_price else 0 end),0) f_price1,
		isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_gas else 0 end),0) f_gas1,
		isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_money else 0 end),0) f_money1,
		isnull(sum(case when f_price_name='阶梯2' then f_price else 0 end),0) f_price2,
		isnull(sum(case when f_price_name='阶梯2' then f_gas else 0 end),0) f_gas2,
		isnull(sum(case when f_price_name='阶梯2' then f_money else 0 end),0) f_money2,
		isnull(sum(case when f_price_name='阶梯3' then f_price else 0 end),0) f_price3,
		isnull(sum(case when f_price_name='阶梯3' then f_gas else 0 end),0) f_gas3,
		isnull(sum(case when f_price_name='阶梯3' then f_money else 0 end),0) f_money3
	from t_chargeprice
	where f_state='有效' and f_gas>0
	group by f_hand_id
) c on h.id=c.f_hand_id
               WHERE f_meter_state = '已抄表' AND f_hand_state = '有效'
                 AND f_user_id = '{f_user_id}'
                 and f_input_date >=  '{startDate}' and f_input_date <= getdate()
               union
/** 查询用户抄表明细 **/
               SELECT
                   f_oughtamount,
                   f_oughtfee,
                   f_tablebase,
                   f_last_tablebase,
                   f_balance,
                   f_curbalance,
                   f_input_date,
                   c.*
               FROM t_web_handplan h with(nolock)
                   left join (
                   select
                   f_hand_id,
                   isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_price else 0 end),0) f_price1,
                   isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_gas else 0 end),0) f_gas1,
                   isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_money else 0 end),0) f_money1,
                   isnull(sum(case when f_price_name='阶梯2' then f_price else 0 end),0) f_price2,
                   isnull(sum(case when f_price_name='阶梯2' then f_gas else 0 end),0) f_gas2,
                   isnull(sum(case when f_price_name='阶梯2' then f_money else 0 end),0) f_money2,
                   isnull(sum(case when f_price_name='阶梯3' then f_price else 0 end),0) f_price3,
                   isnull(sum(case when f_price_name='阶梯3' then f_gas else 0 end),0) f_gas3,
                   isnull(sum(case when f_price_name='阶梯3' then f_money else 0 end),0) f_money3
                   from t_chargeprice
                   where f_state='有效' and f_gas>0
                   group by f_hand_id
                   ) c on h.id=c.f_hand_id
               WHERE f_meter_state = '已抄表' AND f_hand_state = '有效'
                 AND f_user_id = '{f_user_id}'
                 and f_input_date >=  '{startDate}' and f_input_date <= getdate()
              )ml
ORDER BY f_input_date DESC

==> weixin2-1.0.18.jar: wechat/sqls/newproduct/searchUserHandPlanDetailToNew.sql <==
/** 查询用户抄表明细 **/
select * from (SELECT
                   f_oughtamount,
                   f_oughtfee,
                   f_tablebase,
                   f_last_tablebase,
                   f_balance,
                   f_curbalance,
                   f_input_date,
                   c.*
               FROM t_handplan h with(nolock)
left join (
	select
		f_hand_id,
		isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_price else 0 end),0) f_price1,
		isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_gas else 0 end),0) f_gas1,
		isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_money else 0 end),0) f_money1,
		isnull(sum(case when f_price_name='阶梯2' then f_price else 0 end),0) f_price2,
		isnull(sum(case when f_price_name='阶梯2' then f_gas else 0 end),0) f_gas2,
		isnull(sum(case when f_price_name='阶梯2' then f_money else 0 end),0) f_money2,
		isnull(sum(case when f_price_name='阶梯3' then f_price else 0 end),0) f_price3,
		isnull(sum(case when f_price_name='阶梯3' then f_gas else 0 end),0) f_gas3,
		isnull(sum(case when f_price_name='阶梯3' then f_money else 0 end),0) f_money3
	from t_chargeprice
	where f_state='有效' and f_gas>0
	group by f_hand_id
) c on h.id=c.f_hand_id
               WHERE f_meter_state = '已抄表' AND f_hand_state = '有效'
                 AND f_user_id = '{f_user_id}'
                 AND f_input_date > { entity.findDialect() == $SqlServer$: $'{startDate}'$, $to_date('{startDate}','yyyy-mm-dd HH24:mi:ss')$}
               union
/** 查询用户抄表明细 **/
               SELECT
                   f_oughtamount,
                   f_oughtfee,
                   f_tablebase,
                   f_last_tablebase,
                   f_balance,
                   f_curbalance,
                   f_input_date,
                   c.*
               FROM t_web_handplan h with(nolock)
                   left join (
                   select
                   f_hand_id,
                   isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_price else 0 end),0) f_price1,
                   isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_gas else 0 end),0) f_gas1,
                   isnull(sum(case when f_price_name='阶梯1' or f_price_name='固定气价' then f_money else 0 end),0) f_money1,
                   isnull(sum(case when f_price_name='阶梯2' then f_price else 0 end),0) f_price2,
                   isnull(sum(case when f_price_name='阶梯2' then f_gas else 0 end),0) f_gas2,
                   isnull(sum(case when f_price_name='阶梯2' then f_money else 0 end),0) f_money2,
                   isnull(sum(case when f_price_name='阶梯3' then f_price else 0 end),0) f_price3,
                   isnull(sum(case when f_price_name='阶梯3' then f_gas else 0 end),0) f_gas3,
                   isnull(sum(case when f_price_name='阶梯3' then f_money else 0 end),0) f_money3
                   from t_chargeprice
                   where f_state='有效' and f_gas>0
                   group by f_hand_id
                   ) c on h.id=c.f_hand_id
               WHERE f_meter_state = '已抄表' AND f_hand_state = '有效'
                 AND f_user_id = '{f_user_id}'
                 AND f_input_date > { entity.findDialect() == $SqlServer$: $'{startDate}'$, $to_date('{startDate}','yyyy-mm-dd HH24:mi:ss')$}
              )ml
ORDER BY f_input_date DESC
